//! # etree
//!
//! `etree` is a DOM library for XML files.

mod etreenode;
mod etree;

pub use self::etreenode::ETreeNode;
pub use self::etree::ETree;
